==> mls-0.2.tar.gz: mls-0.2/src/command.cpp <==
#include "command.h"
#include "commandimp.h"

using namespace MLS;

void Command::Init()
{
	func["left"]		= &CommandImp::Key_Left;
	func["right"]		= &CommandImp::Key_Right;
	func["up"]			= &CommandImp::Key_Up;
	func["down"]		= &CommandImp::Key_Down;
	func["home"]		= &CommandImp::Key_Home;
	func["end"]			= &CommandImp::Key_End;
	func["pgup"]		= &CommandImp::Key_PageUp;
	func["pgdn"]		= &CommandImp::Key_PageDown;
	func["enter"]		= &CommandImp::Key_Enter;
	
	func["del"]         = &CommandImp::Remove;
	func["remove"]      = &CommandImp::Remove;
	func["editconfig"]  = &CommandImp::Editconfig;
	func["editcolorset"]= &CommandImp::Editcolorset;
	func["about"]       = &CommandImp::About;
	func["help"]        = &CommandImp::Help;
	func["exit"]        = &CommandImp::Exit;
	func["menu"]        = &CommandImp::Menu;
	func["refresh"]     = &CommandImp::Refresh;
	func["mcd"]         = &CommandImp::Mcd;
	func["copy"]        = &CommandImp::Copy;
	func["move"]        = &CommandImp::Move;
	func["edit"]        = &CommandImp::Edit;
	func["view"]        = &CommandImp::View;
	func["mkdir"]       = &CommandImp::Mkdir;
	func["rename"]      = &CommandImp::Rename;
	
	func["back"]		= &CommandImp::Back;
	func["forward"]		= &CommandImp::Forward;
	
	func["showhidden"]	= &CommandImp::ShowHidden;
	func["select"]      = &CommandImp::Select;
	func["viewscreen"]	= &CommandImp::ViewScreen;
	func["shell"]		= &CommandImp::Shell;
}

Command::Command() : _imp(new CommandImp)
{
}

Command::~ Command( )
{
	delete _imp;
}

void Command::SetPanel(Panel *p)
{
	_imp->SetPanel(p);
}
int Command::Execute( const std::string & str )
{
	if (str.empty()) return 0;
	
	if (*str.begin() == '<' && *(str.end()-1) == '>')
	{//  < > 로 둘러쌓인 문자열에 대해서.	
		FuncMap::iterator i;
		
		if ((i = func.find(str.substr(1, str.size()-2))) != func.end())
		{
			(_imp->*((*i).second))();
		}
		else
		{
			MsgBox(COLOR_RED, "에러", "요청하신 커맨드가 없습니다 : %s", str.c_str());
		}
	}
	else
	{// 일반적 문자열 처리 ( 실행 )
		return ParseAndRun(str);

	}	
	return 0;
}

int MLS::Command::Run( const std::string &str, bool bPause)
{
	_imp->Run(str, bPause);
}

int MLS::Command::ParseAndRun( const std::string & str )
{
	_imp->ParseAndRun(str);
}

==> mls-0.3.5.tar.gz: mls-0.3.5/src/command.cpp <==
#include "command.h"
#include "commandimp.h"

using namespace MLS;

void Command::Init()
{
	// -- Key
	func["left"]		= &CommandImp::Key_Left;
	func["right"]		= &CommandImp::Key_Right;
	func["up"]			= &CommandImp::Key_Up;
	func["down"]		= &CommandImp::Key_Down;
	func["home"]		= &CommandImp::Key_Home;
	func["end"]			= &CommandImp::Key_End;
	func["pgup"]		= &CommandImp::Key_PageUp;
	func["pgdn"]		= &CommandImp::Key_PageDown;
	func["enter"]		= &CommandImp::Key_Enter;
	
	// -- select
	func["select"]      = &CommandImp::Select;
	func["selectall"]   = &CommandImp::SelectAll;
	func["selectinvert"]= &CommandImp::SelectInvert;
	
	// -- shell	
	func["shell"]		= &CommandImp::Shell;
	//func["shellparam"]= &CommandImp::Shell;
	func["viewconsole"]	= &CommandImp::ViewScreen;
	
	// -- file	
	func["copy"]        = &CommandImp::Copy;
	func["move"]        = &CommandImp::Move;
	func["del"]         = &CommandImp::Remove;
	func["remove"]      = &CommandImp::Remove;
	func["rename"]      = &CommandImp::Rename;
	//func["newfile"]		= &CommandImp::NewFile;
	
	// -- dir
	func["mkdir"]       = &CommandImp::Mkdir;
	func["mcd"]         = &CommandImp::Mcd;
	// func["qcd"]		= &CommandImp::Qcd;
	func["goroot"]		= &CommandImp::GotoRoot;
	func["gohome"]		= &CommandImp::GotoHome;
	func["goup"]		= &CommandImp::GotoUpperDirectory;
	
	
	// -- panel
	func["refresh"]     = &CommandImp::Refresh;
	
	// -- archive
	func["extract"]     = &CommandImp::Extract;
	//func["archive"]		= 
	
	// -- history
	func["back"]		= &CommandImp::Back;
	func["forward"]		= &CommandImp::Forward;
	//func["history"]		= 
	
	// -- window
	func["split"]		= &CommandImp::Split;
	func["nextwindow"]  = &CommandImp::NextWindow;	
	
	// --sort
	func["sortname"]	= &CommandImp::SortName;
	func["sortext"]		= &CommandImp::SortExt;
	func["sortcolor"]	= &CommandImp::SortColor;
	func["sortsize"]	= &CommandImp::SortSize;
	func["sorttime"]	= &CommandImp::SortTime;
	
	// -- clipboard	
	func["copyclip"]    = &CommandImp::CopyClip;
	func["cutclip"]     = &CommandImp::CutClip;
	func["pasteclip"]   = &CommandImp::PasteClip;
	
	// -- etc	
	func["showhidden"]	= &CommandImp::ShowHidden;	
	func["editconfig"]  = &CommandImp::EditConfig;
	func["editcolorset"]= &CommandImp::EditColorset;
	func["editkeybind"] = &CommandImp::EditKeybind;
	func["exit"]        = &CommandImp::Exit;		
	
	func["about"]       = &CommandImp::About;
	func["help"]        = &CommandImp::Help;	
	func["menu"]        = &CommandImp::Menu;	
		
	func["edit"]        = &CommandImp::Edit;
	func["view"]        = &CommandImp::View;
	func["boxcodechange"]= &CommandImp::BoxCodeChange;
	
	
}

Command::Command() : _imp(new CommandImp)
{
}

Command::~ Command( )
{
	delete _imp;
}

void Command::SetPanel(Panel *p)
{
	_imp->SetPanel(p);
}
int Command::Execute( const std::string & str )
{
	if (str.empty()) return 0;
	
	if (*str.begin() == '<' && *(str.end()-1) == '>')
	{//  < > 로 둘러쌓인 문자열에 대해서.	
		FuncMap::iterator i;
		
		if ((i = func.find(str.substr(1, str.size()-2))) != func.end())
		{
			(_imp->*((*i).second))();
		}
		else
		{
			MsgBox(COLOR_RED, "에러", "요청하신 커맨드가 없습니다 : %s", str.c_str());
		}
	}
	else
	{// 일반적 문자열 처리 ( 실행 )
		return ParseAndRun(str);

	}	
	return 0;
}

int MLS::Command::Run( const std::string &str, bool bPause)
{
	_imp->Run(str, bPause);
}

int MLS::Command::ParseAndRun( const std::string & str )
{
	_imp->ParseAndRun(str);
}
